from functools import wraps
from flask import current_app, request
from htmlmin import minify


class HMin(object):
    def __init__(self, app=None):
        self.app = app
        if app is not None:
            self.init_app(app)
        self._compress_routes = set()

    def init_app(self, app):
        app.config.setdefault('HMIN_COMPRESS_HTML', False)
        if app.config['HMIN_COMPRESS_HTML']:
            app.after_request(self.set_response)

    def set_response(self, response):
        if response.content_type == u'text/html; charset=utf-8':
            endpoint = request.endpoint or ''
            view_func = current_app.view_functions.get(endpoint, None)
            name = (
                '%s.%s' % (view_func.__module__, view_func.__name__)
                if view_func else ''
            )
            content = response.data.decode('utf-8')
            if name in self._compress_routes:
                return response
            compress = minify(content.replace("\n", ""), remove_all_empty_space=True)
            response.set_data(compress)
            return response
        return response

    def not_compress(self, func):
        name = '%s.%s' % (func.__module__, func.__name__)

        @wraps(func)
        def __inner(*a, **k):
            return func(*a, **k)

        self._compress_routes.add(name)
        return __inner



#!/usr/bin/env python

from setuptools import setup

with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='Flask-Hmin',
    version='1.0.1',
    url='https://github.com/zhenzi0322/Flask-Hmin',
    license='BSD-3-Clause',
    author='Long',
    author_email='82131529@qq.com',
    description="Flask压缩Html",
    long_description=long_description,
    long_description_content_type='text/markdown',
    py_modules=['HMIN'],
    packages=['flask_hmin'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'Flask',
        'htmlmin'
    ],
    python_requires='>=3.6',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Markup :: HTML',
    ],
)